%global _hardened_build 1

Name:		geoipupdate
Version:	3.1.1
Release:	2%{?dist}
Summary:	Update GeoIP2 and GeoIP Legacy binary databases from MaxMind
License:	GPLv2
URL:		http://dev.maxmind.com/geoip/geoipupdate/
Source0:	http://github.com/maxmind/geoipupdate/releases/download/v%{version}/geoipupdate-%{version}.tar.gz
Source1:	geoipupdate.cron
BuildRequires:	coreutils
BuildRequires:	crontabs
BuildRequires:	gcc
BuildRequires:	libcurl-devel
BuildRequires:	make
BuildRequires:	sed
BuildRequires:	wget
BuildRequires:	zlib-devel

# Legacy databases fetched by cron6 sub-package no longer available
Obsoletes:	geoipupdate-cron6 < %{version}-%{release}

%description
The GeoIP Update program performs automatic updates of GeoIP2 and GeoIP
Legacy binary databases.

%package cron
Summary:	Cron job to do weekly updates of GeoIP databases
BuildArch:	noarch
Requires:	%{name} = %{version}-%{release}
Requires:	crontabs
Obsoletes:	GeoIP-update < 1.6.0
Provides:	GeoIP-update = 1.6.0

%description cron
Cron job for weekly updates to GeoIP2 and GeoIP Legacy binary databases from
MaxMind.

%prep
%setup -q

%build
%configure --disable-static --disable-dependency-tracking
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot}

# We'll package the documentation ourselves
rm -rf %{buildroot}%{_datadir}/doc/geoipupdate

install -D -m 755 %{SOURCE1} %{buildroot}%{_sysconfdir}/cron.weekly/geoipupdate

%files
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc conf/GeoIP.conf.default README.md ChangeLog.md
%config(noreplace) %{_sysconfdir}/GeoIP.conf
%{_bindir}/geoipupdate
%dir %{_datadir}/GeoIP/
%{_mandir}/man1/geoipupdate.1*
%{_mandir}/man5/GeoIP.conf.5*

%files cron
%config(noreplace) %{_sysconfdir}/cron.weekly/geoipupdate

%changelog
* Mon Jan 21 2019 Paul Howarth <paul@city-fan.org> - 3.1.1-2
- Don't try to update the free legacy GeoIP databases as they are no longer
  distributed by upstream
- Drop the cron6 sub-package as the files it tries to download are no longer
  distributed by upstream

* Tue Sep 11 2018 Paul Howarth <paul@city-fan.org> - 3.1.1-1
- Update to 3.1.1
  - Allow parsing of license keys longer than 12 characters

* Fri Aug 17 2018 Paul Howarth <paul@city-fan.org> - 3.1.0-1
- Update to 3.1.0
  Changes in version 3.0.0:
  - BREAKING CHANGE: When downloading the free databases without a MaxMind
    account, you must either not have 'AccountID', 'UserId', or 'LicenseKey'
    set in your configuration file or they must be set to the zero values
    previously recommended in our documentation; any other value will cause an
    authorization error
  - BREAKING CHANGE: The configuration options 'Protocol',
    'SkipPeerVerification', and `SkipHostnameVerification` are no longer
    supported; if they are present in the configuration file, they will be
    ignored - HTTPS with peer and hostname verification will be used on all
    requests
  - BREAKING CHANGE: The configuration file must have the 'AccountID' or the
    deprecated 'UserId' when downloading a paid database; previously, when
    downloading the GeoIP Legacy Country database, you were able to only
    provide the 'LicenseKey'
  - IMPORTANT: 'geoipupdate-pureperl.pl' has been removed and will no longer be
    distributed with 'geoipupdate'; this Perl script had known issues and did
    not have feature parity with the C implementation
  - This program no longer uses the following endpoints:
    '/app/update_getipaddr', '/app/update', and '/app/update_secure';
    '/geoip/databases/{edition_id}/update' is now used instead
  - Fixed issue in 'gu_strnlen()' dereferencing a pointer before checking that
    it was in array bounds
  - We now update the default GeoIP.conf during installation so that directory
    paths match build parameters; previously this config always said the data
    directory was under /usr/local/share which was not always accurate
  - Improve the error checking and display the underlying reason for the error
    when possible (GH#82)
  - Document that the 'LockFile' is not removed from the filesystem after a
    successful exit from the program (GH#79)
  - Make default configuration directory agree with default installation
    directory
  Changes in version 3.0.1:
  - When there were no updates available, 3.0.0 incorrectly returned an exit
    code of 1 instead of 0; this release reverts to the pre-3.0.0 behavior,
    returning an exit code of 0 in this case
  Changes in version 3.1.0:
  - This version restores the ability to use the 'AccountID'/'UserId' 999999
    along with an all-zero license key when downloading free databases;
    however, the use of this combination is not recommended and may break in
    future versions
  - When printing verbose output, only the first four characters of the
    'LicenseKey' will now be displayed

* Fri Jul 13 2018 Paul Howarth <paul@city-fan.org> - 2.5.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Mon Feb 19 2018 Paul Howarth <paul@city-fan.org> - 2.5.0-2
- Add build-requires for everything we use and depend on

* Tue Oct 31 2017 Paul Howarth <paul@city-fan.org> - 2.5.0-1
- Update to 2.5.0
  - Replace use of strnlen() due to lack of universal availability (GH#71)
  - Document the 'LockFile' option in the 'GeoIP.conf' man page (GH#64)
  - Remove unused base64 library (GH#68)
  - Add the new configuration option 'PreserveFileTimes'; if set, the
    downloaded files will get the same modification times as their original on
    the server (default is '0') (GH#63)
  - Use the correct types when calling 'curl_easy_setopt()'; this fixes
    warnings generated by libcurl's 'typecheck-gcc.h' (GH#61)
  - In 'GeoIP.conf', the 'UserId' option was renamed to 'AccountID' and the
    'ProductIds' option was renamed to 'EditionIDs'; the old options will
    continue to work, but upgrading to the new names is recommended for
    forward compatibility

* Thu Aug  3 2017 Paul Howarth <paul@city-fan.org> - 2.4.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Paul Howarth <paul@city-fan.org> - 2.4.0-2
- BR: perl-generators unconditionally

* Fri May 26 2017 Paul Howarth <paul@city-fan.org> - 2.4.0-1
- Update to 2.4.0
  - geoipupdate now checks that the database directory is writable: if it is
    not, it reports the problem and aborts
  - geoipupdate now acquires a lock when starting up to ensure only one
    instance may run at a time: a new option, 'LockFile', exists to set the
    file to use as a lock ('.geoipupdate.lock' in the database directory by
    default)
  - geoipupdate now prints out additional information from the server when a
    download request results in something other than HTTP status 2xx; this
    provides more information when the API does not respond with a database
    file
  - ${datarootdir}/GeoIP is now created on 'make install' (GH#29)
  - Previously, a variable named 'ERROR' was used, which caused issues building
    on Windows (GH#36)
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - noarch subpackages always available now
  - libcurl-devel always available now

* Fri Feb 10 2017 Paul Howarth <paul@city-fan.org> - 2.3.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Jan  5 2017 Paul Howarth <paul@city-fan.org> - 2.3.1-1
- Update to 2.3.1
  - geoipupdate now uses TCP keep-alive when compiled with cURL 7.25 or
    greater
  - Previously, on an invalid gzip file, geoipupdate would output binary data
    to stderr; it now displays an appropriate error message
  - Install README, ChangeLog, GeoIP.conf.default etc. into docdir (GH#33)
  - $(sysconfdir) is now created if it doesn't exist (GH#33)
  - The sample config file is now usable (GH#33)

* Wed Aug  3 2016 Paul Howarth <paul@city-fan.org> - 2.2.2-3
- BR: perl-generators for proper dependency generation

* Thu Feb  4 2016 Paul Howarth <paul@city-fan.org> - 2.2.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jan 22 2016 Paul Howarth <paul@city-fan.org> - 2.2.2-1
- Update to 2.2.2
  - geoipupdate now calls fsync on the database directory after a rename to
    make it durable in the event of a crash
- Update autotools patch

* Wed Jun 17 2015 Paul Howarth <paul@city-fan.org> - 2.2.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Apr 13 2015 Paul Howarth <paul@city-fan.org> - 2.2.1-2
- Split patch for upstream issue #26 into separate patches for upstream changes
  and effect of running autotools

* Thu Mar  5 2015 Paul Howarth <paul@city-fan.org> - 2.2.1-1
- Update to 2.2.1
  - geoipupdate now verifies the MD5 of the new database before deploying it;
    if the database MD5 does not match the expected MD5, geoipupdate will exit
    with an error
  - The copy of 'base64.c' and 'base64.h' was switched to a version under
    GPLv2+ to prevent a license conflict
  - The 'LICENSE' file was added to the distribution
  - Several issues in the documentation were fixed

* Tue Feb 10 2015 Paul Howarth <paul@city-fan.org> - 2.1.0-4
- New geoipupdate6 cron script written in Perl that doesn't download the data
  if it hasn't changed

* Tue Feb  3 2015 Paul Howarth <paul@city-fan.org> - 2.1.0-3
- Add cron6 subpackage, equivalent to old GeoIP-update6 package
- Revise obsoletes/provides
- Add buildroot and clean for EL-5 compatibility

* Sun Feb  1 2015 Philip A. Prindeville <philipp@fedoraproject.org> - 2.1.0-2
- Remove architecture-specific dependency in noarch subpackage

* Mon Jan 26 2015 Philip A. Prindeville <philipp@fedoraproject.org> - 2.1.0-1
- Initial review package (generated by rpmdev-newspec)

